#
# spec file for package happy
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with tests
Name:           happy
Version:        1.20.1.1
Release:        2.9
Summary:        Happy is a parser generator for Haskell
License:        BSD-2-Clause
URL:            https://hackage.haskell.org/package/%{name}
Source0:        https://hackage.haskell.org/package/%{name}-%{version}/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  docbook-dtd
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-array-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  libxml2
BuildRequires:  libxslt
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-process-prof
%endif

%description
Happy is a parser generator for Haskell. Given a grammar specification in BNF,
Happy generates Haskell code to parse the grammar. Happy works in a similar way
to the 'yacc' tool for C.

%prep
%autosetup

%build
%define cabal_configure_options -f-bootstrap
%ghc_bin_build
cd doc
autoreconf
%configure
%make_build html

%install
%ghc_bin_install
# drop artifacts from autoconf that differ across builds to fix build-compare
rm -rf doc/autom4te.cache doc/config.log doc/config.status

install -D --mode=444 doc/%{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1

%check
%cabal_test

%files
%license LICENSE
%doc ChangeLog.md doc examples
%{_bindir}/%{name}
%dir %{_datadir}/%{name}-%{version}
%{_mandir}/man1/*
%{_datadir}/%{name}-%{version}/GLR_Base
%{_datadir}/%{name}-%{version}/GLR_Lib
%{_datadir}/%{name}-%{version}/GLR_Lib-ghc
%{_datadir}/%{name}-%{version}/GLR_Lib-ghc-debug
%{_datadir}/%{name}-%{version}/HappyTemplate
%{_datadir}/%{name}-%{version}/HappyTemplate-arrays
%{_datadir}/%{name}-%{version}/HappyTemplate-arrays-coerce
%{_datadir}/%{name}-%{version}/HappyTemplate-arrays-coerce-debug
%{_datadir}/%{name}-%{version}/HappyTemplate-arrays-debug
%{_datadir}/%{name}-%{version}/HappyTemplate-arrays-ghc
%{_datadir}/%{name}-%{version}/HappyTemplate-arrays-ghc-debug
%{_datadir}/%{name}-%{version}/HappyTemplate-coerce
%{_datadir}/%{name}-%{version}/HappyTemplate-ghc

%changelog
* Wed Oct  4 2023 Peter Simons <psimons@suse.com>
- Drop obsolete code to remove +x permission from data files.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Tue Feb  7 2023 Peter Simons <psimons@suse.com>
- Update happy to version 1.20.1.1.
  Upstream has not updated the file "ChangeLog.md" since the last
  release.
* Mon Feb  6 2023 Peter Simons <psimons@suse.com>
- Update happy to version 1.20.1 revision 1.
  Upstream has renamed and modified the change log file(s) in this
  release. Unfortunately, the automatic updater cannot reliable
  determine relevant entries for this release.
* Sun May  8 2022 Peter Simons <psimons@suse.com>
- Update happy to version 1.20.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Feb 10 2022 psimons@suse.com
- Downgrade to version 1.20.0.
  Upstream has retracted release 1.21.0 on Hackage.
* Mon Nov  1 2021 psimons@suse.com
- Update happy to version 1.21.0.
  Upstream has renamed and modified the change log file(s) in this
  release. Unfortunately, the automatic updater cannot reliable
  determine relevant entries for this release.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Wed Aug 26 2020 psimons@suse.com
- Update happy to version 1.20.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/happy-1.20.0/src/CHANGES
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Wed Sep  4 2019 psimons@suse.com
- Update happy to version 1.19.12.
  1.19.12
  * Fix for building with GHC 8.8.x
  * Move custom Setup preprocessing steps into a separate
    executable, like Alex
  - ----------------------------------------------------------------------------
* Fri Jun  7 2019 psimons@suse.com
- Update happy to version 1.19.11.
  1.19.11
  * Fix for building with GHC 8.6.x
  - ----------------------------------------------------------------------------
* Fri May 10 2019 psimons@suse.com
- Update happy to version 1.19.10.
  1.19.10
  * Fix polymorphic (rank-n) non-terminals
  * Fix for GHC 8.8.1
  - ----------------------------------------------------------------------------
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Update Cabal build instructions to support ghc-8.6.1.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Wed Jun 13 2018 ptrommler@icloud.com
- Another tweak for SLE 12
  * use plain make to build documentation
* Tue Jun 12 2018 ptrommler@icloud.com
- Fix build on SLE 12 SP 3
  * configure in doc directory chokes on
  - -disable-dependency-tracking
* Wed May 16 2018 psimons@suse.com
- Update to version 1.19.9.
  * Fix build with GHC 8.4.1-alpha
  * Fix issue #94 (some grammars don't compile due to new type
    signatures introduced to allow overloading to be used)
  * Fix misisng test suite files in the sdist
  * Manually generate Parser.hs using Makefile before sdist,
    to fix bootstrapping problems with cabal sandboxes & new-build
  * Documentation fixes
  * Fixed GLR support
  * new option -p/--pretty prints the grammar rules (only) to a file
  * Added generation of additional type signatures to enable use
    of typeclasses in monadic parsers.
  * Code cleanups (thanks Index Int <vlad.z.4096@gmail.com>)
  * fix for GHC 7.10 (Applicative/Monad, #19, #21)
  * fix for GHC 7.2 (#16)
  * fixes for clang (XCode 5)
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Tue Jul 11 2017 bwiedemann@suse.com
- Drop build logs from rpm to fix build-compare
* Sat Apr 29 2017 psimons@suse.com
- Update to version 1.19.5 revision 2 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.19.5 revision 1 with cabal2obs.
* Wed May 13 2015 mimi.vx@gmail.com
- temporary disable tests
* Thu Apr  9 2015 mimi.vx@gmail.com
- update to 1.19.5
* Mon Feb  2 2015 peter.trommler@ohm-hochschule.de
- downgrade to 1.19.4
  * strict version requirement by Haskell Platform
* Mon Feb  2 2015 mimi.vx@gmail.com
- change line endings from dos to unix in examples
* Sun Jan 18 2015 mimi.vx@gmail.com
- update to 1.19.5
- remove rpmlintrc
  * fixes for GHC 7.10
  * Code cleanups (thanks Index Int <vlad.z.4096@gmail.com>)
* Mon Nov 24 2014 mimi.vx@gmail.com
- change licence to BSD-2-Clause
* Sun Nov 23 2014 mimi.vx@gmail.com
- typo in Summary
* Sun Nov 23 2014 mimi.vx@gmail.com
- add tests
- suppres warnings with rpmlintrc
- spec file cleanup with cabal-rpm and spec-cleaner
* Fri Sep 12 2014 peter.trommler@ohm-hochschule.de
- update to 1.19.4
  * fix manual page
  * fix build with ghc 7.8 and (future) 7.10
  * Haskell Platform 2014.2.0.0
- drop happy-1.18.6-generate-man-page.patch
  * fixed upstream
* Sat Aug 23 2014 peter.trommler@ohm-hochschule.de
- enable PowerPC builds
* Mon May  6 2013 peter.trommler@ohm-hochschule.de
- spec file cleanup and reformatting by OBS service
* Thu Dec 27 2012 peter.trommler@ohm-hochschule.de
- fixed license tag
* Sat Nov 17 2012 peter.trommler@ohm-hochschule.de
- make service localonly for Factory submission
* Mon Oct  1 2012 peter.trommler@ohm-hochschule.de
- update to 1.18.10 from upstream for Haskell Platform 2012.4.0.0
* Sun Jun 10 2012 peter.trommler@ohm-hochschule.de
- dropped BuildRequires xmltex (not needed)
* Tue Jun  5 2012 peter.trommler@ohm-hochschule.de
- update to 1.18.9 from upstream for Haskell Platform 2012.2.0.0
* Mon May  7 2012 peter.trommler@ohm-hochschule.de
- patch file added
* Mon May  7 2012 peter.trommler@ohm-hochschule.de
- added patch to enable man page generation
- build, install and package man page
* Mon Jan 23 2012 peter.trommler@ohm-hochschule.de
- SPDX compliant version tag
- BR autoconf explicitly
* Mon Dec  5 2011 peter.trommler@ohm-hochschule.de
- Fixed ExclusiveArch for OBS
- Added ghc-mtl-devel BR
* Thu Nov 24 2011 peter.trommler@ohm-hochschule.de
- Initial packaging.
